@@ -5,43 +5,36 @@ import altair as alt
 import pandas as pd
 
 from smoltools.fret0.efficiency import generate_r0_curve
-import smoltools.calculate.distance as distance
 import smoltools.resources.colors as colors
 from smoltools.fret0.utils import lower_triangle, sort_table
 
 
+def _get_size(n_residues: int) -> int:
+    MAX_SIZE = 600
+    return min(MAX_SIZE, n_residues * 10)
+
+
 def _distance_map_base(df: pd.DataFrame) -> alt.Chart:
     """Common distance map components."""
     df = sort_table(df)
 
-    SIZE = 600
+    n_residues = df.id_1.nunique()
+    size = _get_size(n_residues)
+
+    axis_config = {'sort': None, 'axis': alt.Axis(labels=False, ticks=False)}
+
     return (
         alt.Chart(df)
         .mark_rect()
         .encode(
-            x=alt.X(
-                'id_1:N',
-                title='Residue #',
-                sort=None,
-                axis=alt.Axis(labels=False, ticks=False),
-            ),
-            y=alt.Y(
-                'id_2:N',
-                title='Residue #',
-                sort=None,
-                axis=alt.Axis(labels=False, ticks=False),
-            ),
-        )
-        .properties(
-            width=SIZE,
-            height=SIZE,
+            x=alt.X('id_1:N', title='Residue #', **axis_config),
+            y=alt.Y('id_2:N', title='Residue #', **axis_config),
         )
+        .properties(width=size, height=size)
     )
 
 
-def delta_distance_map(
-    distances_a: pd.DataFrame, distances_b: pd.DataFrame, cutoff: int = 5
-) -> alt.Chart:
+def delta_distance_map(df: pd.DataFrame, cutoff: float = 5) -> alt.Chart:
     """Heatmap of pairwise distance between each alpha carbon between two conformations.
 
     Parameters:
@@ -53,11 +46,7 @@ def delta_distance_map(
     --------
     Chart: Altair chart object.
     """
-    df = (
-        distance._merge_pairwise_distances(distances_a, distances_b)
-        .assign(delta_distance=lambda x: (x.distance_a - x.distance_b))
-        .loc[lambda x: lower_triangle(x) & (x.delta_distance.abs() > cutoff)]
-    )
+    df = df.loc[lambda x: lower_triangle(x) & (x.delta_distance.abs() > cutoff)]
 
     range_max = df.delta_distance.abs().max()
 
